@@ -8,7 +8,7 @@ from .entity import Entity
 from .zone import Zone
 from .token import Token
 from .api_handler import NotFoundError
-from .op_deployment import get_opdeployment
+from .op_deployment import get_op_deployment
 
 
 class Account(Entity):
@@ -204,17 +204,17 @@ class Account(Entity):
         else:
             return Zone(result['id'], result, api=self.api, **kwargs)
 
-    def get_opdeployment(self, opdeployment_id, params=None, raw=False, api_call_kwargs={}):
+    def get_op_deployment(self, op_deployment_id, params=None, raw=False, api_call_kwargs={}):
         """:obj:`Zone`: Fetch the on prem deployment with specified id in the account.
 
         Args:
-            opdeployment_id (str): on prem deployment ID.
+            op_deployment_id (str): on prem deployment ID.
             params (dict): Optional query parameters.
             raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
-        return get_opdeployment(self.api, self._id, opdeployment_id, params=params, raw=raw,
-                                api_call_kwargs=api_call_kwargs)
+        return get_op_deployment(self.api, self._id, op_deployment_id, params=params, raw=raw,
+                                 api_call_kwargs=api_call_kwargs)
 
     def get_alert(self, alert_id, attributes=None, raw=False, params=None, api_call_kwargs={}):
         """:obj:`Alert`: Fetch an Alert by its ID
